@@ -11,9 +11,6 @@ pip install -r requirements.txt
 pip uninstall -y pydantic
 cd .. && pip install . && cd fastapi
 
-# apply the patch designed to get the tests to pass (currently ignores some warnings)
-git apply ../tests/test_fastapi_changes.patch
-
 # ./scripts/test.sh accepts arbitrary arguments and passes them to the pytest call.
 # This may be necessary if we make low-consequence changes to pydantic, such as minor changes the details of a JSON
 # schema or the contents of a ValidationError
