@@ -35,8 +35,10 @@ from pydantic_core import CoreSchema, core_schema
 from typing_extensions import (
     Annotated,
     Literal,
+    NotRequired,
     OrderedDict,
     ParamSpec,
+    TypedDict,
     TypeVarTuple,
     Unpack,
     get_args,
@@ -53,6 +55,7 @@ from pydantic import (
     PositiveInt,
     PydanticSchemaGenerationError,
     PydanticUserError,
+    TypeAdapter,
     ValidationError,
     ValidationInfo,
     computed_field,
@@ -69,6 +72,7 @@ from pydantic._internal._generics import (
     recursively_defined_type_refs,
     replace_types,
 )
+from pydantic.warnings import GenericBeforeBaseModelWarning
 
 
 @pytest.fixture()
@@ -268,7 +272,7 @@ def test_must_inherit_from_generic():
 
     assert str(exc_info.value) == (
         "<class 'tests.test_generics.test_must_inherit_from_generic.<locals>.Result'> cannot be "
-        "parametrized because it does not inherit from typing.Generic"
+        'parametrized because it does not inherit from typing.Generic'
     )
 
 
@@ -1508,6 +1512,22 @@ def test_generic_with_referenced_generic_type_bound():
     ReferenceModel[MyInt]
 
 
+def test_generic_with_referenced_generic_union_type_bound():
+    T = TypeVar('T', bound=Union[str, int])
+
+    class ModelWithType(BaseModel, Generic[T]):
+        some_type: Type[T]
+
+    class MyInt(int):
+        ...
+
+    class MyStr(str):
+        ...
+
+    ModelWithType[MyInt]
+    ModelWithType[MyStr]
+
+
 def test_generic_with_referenced_generic_type_constraints():
     T = TypeVar('T', int, str)
 
@@ -2034,9 +2054,14 @@ def test_generic_subclass_with_extra_type_with_hint_message():
     E = TypeVar('E', bound=BaseModel)
     D = TypeVar('D')
 
-    class BaseGenericClass(Generic[E, D], BaseModel):
-        uid: str
-        name: str
+    with pytest.warns(
+        GenericBeforeBaseModelWarning,
+        match='Classes should inherit from `BaseModel` before generic classes',
+    ):
+
+        class BaseGenericClass(Generic[E, D], BaseModel):
+            uid: str
+            name: str
 
     with pytest.raises(
         TypeError,
@@ -2046,9 +2071,13 @@ def test_generic_subclass_with_extra_type_with_hint_message():
             ' `class ChildGenericClass(BaseGenericClass, typing.Generic[~E, ~D]): ...`'
         ),
     ):
+        with pytest.warns(
+            GenericBeforeBaseModelWarning,
+            match='Classes should inherit from `BaseModel` before generic classes',
+        ):
 
-        class ChildGenericClass(BaseGenericClass[E, Dict[str, Any]]):
-            ...
+            class ChildGenericClass(BaseGenericClass[E, Dict[str, Any]]):
+                ...
 
 
 def test_multi_inheritance_generic_binding():
@@ -2626,9 +2655,14 @@ def test_no_generic_base():
 def test_reverse_order_generic_hashability():
     T = TypeVar('T')
 
-    class Model(Generic[T], BaseModel):
-        x: T
-        model_config = dict(frozen=True)
+    with pytest.warns(
+        GenericBeforeBaseModelWarning,
+        match='Classes should inherit from `BaseModel` before generic classes',
+    ):
+
+        class Model(Generic[T], BaseModel):
+            x: T
+            model_config = dict(frozen=True)
 
     m1 = Model[int](x=1)
     m2 = Model[int](x=1)
@@ -2639,6 +2673,7 @@ def test_serialize_unsubstituted_typevars_bound() -> None:
     class ErrorDetails(BaseModel):
         foo: str
 
+    # This version of `TypeVar` does not support `default` on Python <3.12
     ErrorDataT = TypeVar('ErrorDataT', bound=ErrorDetails)
 
     class Error(BaseModel, Generic[ErrorDataT]):
@@ -2696,6 +2731,68 @@ def test_serialize_unsubstituted_typevars_bound() -> None:
     }
 
 
+def test_serialize_unsubstituted_typevars_bound_default_supported() -> None:
+    class ErrorDetails(BaseModel):
+        foo: str
+
+    # This version of `TypeVar` always support `default`
+    ErrorDataT = TypingExtensionsTypeVar('ErrorDataT', bound=ErrorDetails)
+
+    class Error(BaseModel, Generic[ErrorDataT]):
+        message: str
+        details: ErrorDataT
+
+    class MyErrorDetails(ErrorDetails):
+        bar: str
+
+    sample_error = Error(
+        message='We just had an error',
+        details=MyErrorDetails(foo='var', bar='baz'),
+    )
+    assert sample_error.details.model_dump() == {
+        'foo': 'var',
+        'bar': 'baz',
+    }
+    assert sample_error.model_dump() == {
+        'message': 'We just had an error',
+        'details': {
+            'foo': 'var',
+            'bar': 'baz',
+        },
+    }
+
+    sample_error = Error[ErrorDetails](
+        message='We just had an error',
+        details=MyErrorDetails(foo='var', bar='baz'),
+    )
+    assert sample_error.details.model_dump() == {
+        'foo': 'var',
+        'bar': 'baz',
+    }
+    assert sample_error.model_dump() == {
+        'message': 'We just had an error',
+        'details': {
+            'foo': 'var',
+        },
+    }
+
+    sample_error = Error[MyErrorDetails](
+        message='We just had an error',
+        details=MyErrorDetails(foo='var', bar='baz'),
+    )
+    assert sample_error.details.model_dump() == {
+        'foo': 'var',
+        'bar': 'baz',
+    }
+    assert sample_error.model_dump() == {
+        'message': 'We just had an error',
+        'details': {
+            'foo': 'var',
+            'bar': 'baz',
+        },
+    }
+
+
 @pytest.mark.parametrize(
     'type_var',
     [
@@ -2704,7 +2801,7 @@ def test_serialize_unsubstituted_typevars_bound() -> None:
     ],
     ids=['default', 'constraint'],
 )
-def test_serialize_unsubstituted_typevars_bound(
+def test_serialize_unsubstituted_typevars_variants(
     type_var: Type[BaseModel],
 ) -> None:
     class ErrorDetails(BaseModel):
@@ -2770,3 +2867,20 @@ def test_mix_default_and_constraints() -> None:
 
         class _(BaseModel, Generic[T]):
             x: T
+
+
+def test_generic_with_not_required_in_typed_dict() -> None:
+    T = TypingExtensionsTypeVar('T')
+
+    class FooStr(TypedDict):
+        type: NotRequired[str]
+
+    class FooGeneric(TypedDict, Generic[T]):
+        type: NotRequired[T]
+
+    ta_foo_str = TypeAdapter(FooStr)
+    assert ta_foo_str.validate_python({'type': 'tomato'}) == {'type': 'tomato'}
+    assert ta_foo_str.validate_python({}) == {}
+    ta_foo_generic = TypeAdapter(FooGeneric[str])
+    assert ta_foo_generic.validate_python({'type': 'tomato'}) == {'type': 'tomato'}
+    assert ta_foo_generic.validate_python({}) == {}
